Trait AccessibilityModifiers
pub trait AccessibilityModifiers: Modifiable {
Show 19 methods
// Provided methods
fn role(self, role: Role) -> Self { ... }
fn name<U>(self, name: impl Res<U>) -> Self
where U: ToStringLocalized { ... }
fn labeled_by(self, id: impl Into<String>) -> Self { ... }
fn described_by(self, id: impl Into<String>) -> Self { ... }
fn controls(self, id: impl Into<String>) -> Self { ... }
fn active_descendant<U>(self, id: impl Res<U> + 'static) -> Self
where U: Into<String> + Clone + 'static { ... }
fn live(self, live: Live) -> Self { ... }
fn hidden<U>(self, hidden: impl Res<U>) -> Self
where U: Into<bool> { ... }
fn expanded<U>(self, expanded: impl Res<U>) -> Self
where U: Into<bool> { ... }
fn accessibility_selected<U>(self, selected: impl Res<U>) -> Self
where U: Into<bool> { ... }
fn selected<U>(self, selected: impl Res<U>) -> Self
where U: Into<bool> { ... }
fn multiselectable<U>(self, multiselectable: impl Res<U>) -> Self
where U: Into<bool> { ... }
fn sort_direction(
self,
sort_direction: impl Res<Option<SortDirection>>,
) -> Self { ... }
fn level<U>(self, level: impl Res<U>) -> Self
where U: Into<usize> { ... }
fn size_of_set<U>(self, size_of_set: impl Res<U>) -> Self
where U: Into<usize> { ... }
fn position_in_set<U>(self, position_in_set: impl Res<U>) -> Self
where U: Into<usize> { ... }
fn orientation<U>(self, orientation: impl Res<U>) -> Self
where U: Into<Orientation> { ... }
fn numeric_value<U>(self, value: impl Res<U>) -> Self
where U: Into<f64> { ... }
fn text_value<U>(self, value: impl Res<U>) -> Self
where U: ToStringLocalized { ... }
}Expand description
Modifiers for changing the accessibility properties of a view.
Provided Methods
fn name<U>(self, name: impl Res<U>) -> Selfwhere
U: ToStringLocalized,
fn name<U>(self, name: impl Res<U>) -> Selfwhere
U: ToStringLocalized,
Sets the accessibility name of the view.
fn labeled_by(self, id: impl Into<String>) -> Self
fn labeled_by(self, id: impl Into<String>) -> Self
Sets the accessibility label relationship for the view using the ID of another view.
fn described_by(self, id: impl Into<String>) -> Self
fn described_by(self, id: impl Into<String>) -> Self
Sets the accessibility description relationship for the view using the ID of another view.
fn controls(self, id: impl Into<String>) -> Self
fn controls(self, id: impl Into<String>) -> Self
Sets the accessibility controls relationship for the view using the ID of another view.
fn active_descendant<U>(self, id: impl Res<U> + 'static) -> Self
fn active_descendant<U>(self, id: impl Res<U> + 'static) -> Self
Sets the accessibility active descendant relationship for the view.
Sets whether the view should be hidden from accessibility.
fn expanded<U>(self, expanded: impl Res<U>) -> Self
fn expanded<U>(self, expanded: impl Res<U>) -> Self
Sets whether the view should be announced as expanded (true) or collapsed (false).
fn accessibility_selected<U>(self, selected: impl Res<U>) -> Self
fn accessibility_selected<U>(self, selected: impl Res<U>) -> Self
Sets whether the view should be announced as selected (true) or not selected (false).
fn selected<U>(self, selected: impl Res<U>) -> Self
fn selected<U>(self, selected: impl Res<U>) -> Self
Sets whether the view should be announced as selected (true) or not selected (false).
This is an alias of AccessibilityModifiers::accessibility_selected.
fn multiselectable<U>(self, multiselectable: impl Res<U>) -> Self
fn multiselectable<U>(self, multiselectable: impl Res<U>) -> Self
Sets whether the view allows multiple selected descendants.
fn sort_direction(self, sort_direction: impl Res<Option<SortDirection>>) -> Self
fn sort_direction(self, sort_direction: impl Res<Option<SortDirection>>) -> Self
Sets the accessibility sort direction for sortable headers.
Use None when a header is not currently sorted.
fn size_of_set<U>(self, size_of_set: impl Res<U>) -> Self
fn size_of_set<U>(self, size_of_set: impl Res<U>) -> Self
Sets the total number of sibling items in a set for this item.
fn position_in_set<U>(self, position_in_set: impl Res<U>) -> Self
fn position_in_set<U>(self, position_in_set: impl Res<U>) -> Self
Sets the 1-based position of this item within its sibling set.
fn orientation<U>(self, orientation: impl Res<U>) -> Selfwhere
U: Into<Orientation>,
fn orientation<U>(self, orientation: impl Res<U>) -> Selfwhere
U: Into<Orientation>,
Sets the accessibility orientation of the view. This does not affect the layout of the view, but is used to inform assistive technologies of the orientation of the view.
fn numeric_value<U>(self, value: impl Res<U>) -> Self
fn numeric_value<U>(self, value: impl Res<U>) -> Self
Sets the accessibility numeric value for the view.
fn text_value<U>(self, value: impl Res<U>) -> Selfwhere
U: ToStringLocalized,
fn text_value<U>(self, value: impl Res<U>) -> Selfwhere
U: ToStringLocalized,
Sets the accessibility text value for the view.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.