AccessibilityModifiers

Trait AccessibilityModifiers 

pub trait AccessibilityModifiers: Modifiable {
Show 13 methods // Provided methods fn role(self, role: Role) -> Self { ... } fn name<U>(self, name: impl Res<U>) -> Self where U: ToStringLocalized { ... } fn labeled_by(self, id: impl Into<String>) -> Self { ... } fn described_by(self, id: impl Into<String>) -> Self { ... } fn controls(self, id: impl Into<String>) -> Self { ... } fn active_descendant<U>(self, id: impl Res<U> + 'static) -> Self where U: Into<String> + Clone + 'static { ... } fn live(self, live: Live) -> Self { ... } fn hidden<U>(self, hidden: impl Res<U>) -> Self where U: Into<bool> { ... } fn expanded<U>(self, expanded: impl Res<U>) -> Self where U: Into<bool> { ... } fn selected<U>(self, selected: impl Res<U>) -> Self where U: Into<bool> { ... } fn orientation<U>(self, orientation: impl Res<U>) -> Self where U: Into<Orientation> { ... } fn numeric_value<U>(self, value: impl Res<U>) -> Self where U: Into<f64> { ... } fn text_value<U>(self, value: impl Res<U>) -> Self where U: ToStringLocalized { ... }
}
Modifiers for changing the accessibility properties of a view.

Provided Methods

fn role(self, role: Role) -> Self

Sets the accessibility role of the view.

fn name<U>(self, name: impl Res<U>) -> Self

Sets the accessibility name of the view.

fn labeled_by(self, id: impl Into<String>) -> Self

Sets the accessibility label relationship for the view using the ID of another view.

fn described_by(self, id: impl Into<String>) -> Self

Sets the accessibility description relationship for the view using the ID of another view.

fn controls(self, id: impl Into<String>) -> Self

Sets the accessibility controls relationship for the view using the ID of another view.

fn active_descendant<U>(self, id: impl Res<U> + 'static) -> Self
where U: Into<String> + Clone + 'static,

Sets the accessibility active descendant relationship for the view.

fn live(self, live: Live) -> Self

Sets whether the view should act as an accessibility live region.

fn hidden<U>(self, hidden: impl Res<U>) -> Self
where U: Into<bool>,

Sets whether the view should be hidden from accessibility.

fn expanded<U>(self, expanded: impl Res<U>) -> Self
where U: Into<bool>,

Sets whether the view should be announced as expanded (true) or collapsed (false).

fn selected<U>(self, selected: impl Res<U>) -> Self
where U: Into<bool>,

Sets whether the view should be announced as selected (true) or not selected (false).

fn orientation<U>(self, orientation: impl Res<U>) -> Self
where U: Into<Orientation>,

Sets the accessibility orientation of the view. This does not affect the layout of the view, but is used to inform assistive technologies of the orientation of the view.

fn numeric_value<U>(self, value: impl Res<U>) -> Self
where U: Into<f64>,

Sets the accessibility numeric value for the view.

fn text_value<U>(self, value: impl Res<U>) -> Self

Sets the accessibility text value for the view.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<V> AccessibilityModifiers for Handle<'_, V>
where V: View,